.. contents::

Welcome to the Electric Emissions & Cost Optimizer (EECO) documentation!
========================================================================

.. toctree::
   :maxdepth: 1
   :caption: Overview

   Table of Contents <self>
   purpose
   complexities
   why_metrics
   why_neutral
   why_advanced
   CONTRIBUTING
   LICENSE

.. toctree::
   :maxdepth: 1
   :caption: Tutorials

   hello
   optimize_cost
   optimize_emit
   cooptimize
   tutorial_metrics

.. toctree::
   :maxdepth: 1
   :caption: How-to Guides

   data_format
   how_to_cost
   how_to_emit
   how_to_metrics
   how_to_advanced

.. toctree::
   :maxdepth: 1
   :caption: Code

   costs
   emissions
   metrics
   units
   utils

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`